/*-----------------------------------------------------------------------
sprawl_regr.do

Stata do file to re-create the regressions and summary statistics
in Table IV of the article 'Causes of sprawl: A portrait from space',
by Marcy Burchfield, Henry G. Overman, Diego Puga, and Matthew A. Turner,
Quarterly Journal of Economics 121(2), May 2006.
-----------------------------------------------------------------------*/
#delimit;
clear;
set more off;
capture quietly log close;

log using sprawl_regr,text replace;

use sprawl_msa, clear;

/* summary statistics, table iv */
sum sprawl_1976_92
  sprawl_1992
  sprawl_1976
  central_empl_1977
  streetcar_1902
  avg_dec_popgr1920_70
  sd_dec_popgr1920_70
  pc_aquifer_fringe
  elevat_range_fringe
  ruggedness_fringe
  cooling_dd
  heating_dd
  pc_incorp_fringe
  pc_transfers
  rest_bars
  road_density
  popgr_1970_90
  herfindahl_incorp
  latitude
  longitude;

/* change of units so that regression coefficients give the impact
   on the sprawl index of a one standard deviation increase
   in the corresponding variable. */
egen sdunits__central_empl_1977    =sd(central_empl_1977);
egen sdunits__streetcar_1902       =sd(streetcar_1902);
egen sdunits__avg_dec_popgr1920_70 =sd(avg_dec_popgr1920_70);
egen sdunits__sd_dec_popgr1920_70  =sd(sd_dec_popgr1920_70);
egen sdunits__pc_aquifer_fringe    =sd(pc_aquifer_fringe);
egen sdunits__elevat_range_fringe  =sd(elevat_range_fringe);
egen sdunits__ruggedness_fringe    =sd(ruggedness_fringe);
egen sdunits__cooling_dd           =sd(cooling_dd);
egen sdunits__heating_dd           =sd(heating_dd);
egen sdunits__pc_incorp_fringe     =sd(pc_incorp_fringe);
egen sdunits__pc_transfers         =sd(pc_transfers);
egen sdunits__rest_bars            =sd(rest_bars);
egen sdunits__road_density         =sd(road_density);
egen sdunits__popgr_1970_90        =sd(popgr_1970_90 );
egen sdunits__herfindahl_incorp    =sd(herfindahl_incorp);
egen sdunits__latitude             =sd(latitude);
egen sdunits__longitude            =sd(longitude);
replace pc_aquifer_fringe      = pc_aquifer_fringe    / sdunits__pc_aquifer_fringe;
replace elevat_range_fringe    = elevat_range_fringe  / sdunits__elevat_range_fringe;
replace ruggedness_fringe      = ruggedness_fringe    / sdunits__ruggedness_fringe;
replace cooling_dd             = cooling_dd           / sdunits__cooling_dd;
replace heating_dd             = heating_dd           / sdunits__heating_dd;
replace central_empl_1977      = central_empl_1977    / sdunits__central_empl_1977;
replace streetcar_1902         = streetcar_1902       / sdunits__streetcar_1902;
replace avg_dec_popgr1920_70   = avg_dec_popgr1920_70 / sdunits__avg_dec_popgr1920_70;
replace sd_dec_popgr1920_70    = sd_dec_popgr1920_70  / sdunits__sd_dec_popgr1920_70;
replace pc_incorp_fringe       = pc_incorp_fringe     / sdunits__pc_incorp_fringe;
replace pc_transfers           = pc_transfers         / sdunits__pc_transfers;
replace latitude               = latitude             / sdunits__latitude;
replace longitude              = longitude            / sdunits__longitude;
replace rest_bars              = rest_bars            / sdunits__rest_bars;
replace road_density           = road_density         / sdunits__road_density;
replace herfindahl_incorp      = herfindahl_incorp    / sdunits__herfindahl_incorp;
replace popgr_1970_90          = popgr_1970_90        / sdunits__popgr_1970_90;
drop sdunits_*;

xi, prefix(divd) i.division;

/* regression results, table iv */

* column (1);
regress sprawl_1976_92
  central_empl_1977
  streetcar_1902
  avg_dec_popgr1920_70
  sd_dec_popgr1920_70
  pc_aquifer_fringe
  elevat_range_fringe
  ruggedness_fringe
  cooling_dd heating_dd
  pc_incorp_fringe
  pc_transfers
  , robust;

* column (2);
regress sprawl_1976_92
  central_empl_1977
  streetcar_1902
  avg_dec_popgr1920_70
  sd_dec_popgr1920_70
  pc_aquifer_fringe
  elevat_range_fringe
  ruggedness_fringe
  cooling_dd heating_dd
  pc_incorp_fringe
  pc_transfers
  rest_bars
  road_density
  popgr_1970_90
  herfindahl_incorp
  , robust;

* column (3);
regress sprawl_1976_92
  central_empl_1977
  streetcar_1902
  avg_dec_popgr1920_70
  sd_dec_popgr1920_70
  pc_aquifer_fringe
  elevat_range_fringe
  ruggedness_fringe
  cooling_dd heating_dd
  pc_incorp_fringe
  pc_transfers
  latitude longitude
  divd*
  , robust;

* column (4);
regress sprawl_1992
  central_empl_1977
  streetcar_1902
  avg_dec_popgr1920_70
  sd_dec_popgr1920_70
  pc_aquifer_fringe
  elevat_range_fringe
  ruggedness_fringe
  cooling_dd heating_dd
  pc_incorp_fringe
  pc_transfers
  , robust;

log close;

exit;
